@@ -513,13 +513,13 @@ void init_eventparticle(pybind11::module m){
   pybind11::class_<Class, std::shared_ptr<Class>> ev_particle(m, "EventParticle");
   ev_particle.def(pybind11::init<>());
 
-  ev_particle.def("set",     &Class::set);
-  ev_particle.def("append",     &Class::append);
-  // ev_particle.def("emplace_back",    &Class::emplace_back);
-  // ev_particle.def("emplace", &Class::emplace);
-  ev_particle.def("as_vector", &Class::as_vector);
-  ev_particle.def("size", &Class::size);
-  ev_particle.def("clear", &Class::clear);
+  ev_particle.def("set",             &Class::set);
+  ev_particle.def("append",          &Class::append);
+  // ev_particle.def("emplace_back", &Class::emplace_back);
+  ev_particle.def("at",              &Class::at);
+  ev_particle.def("as_vector",       &Class::as_vector);
+  ev_particle.def("size",            &Class::size);
+  ev_particle.def("clear",           &Class::clear);
 
 
 /*
