@@ -2,7 +2,7 @@
  * \file larbys.h
  *
  * \ingroup core_Base
- * 
+ *
  * \brief Class def header for exception classes for larcv3 framework
  *
  * @author cadams
@@ -33,13 +33,13 @@
 #include "Voxel.h"
 
 #ifndef LARCV_NO_PYBIND
-
+#ifdef LARCV_INTERNAL
+#include <pybind11/pybind11.h>
 __attribute__ ((visibility ("default"))) void init_dataformat(pybind11::module m);
-
-
+#endif
 // bindings
 #endif
 
 
 // include guards
-#endif
\ No newline at end of file
+#endif
